aboutsummaryrefslogtreecommitdiffstats
path: root/resources
diff options
context:
space:
mode:
authorJan Gelety <jgelety@cisco.com>2017-12-05 14:27:26 +0100
committerTibor Frank <tifrank@cisco.com>2017-12-15 09:29:51 +0000
commit0ba508f0eac819c1985e825857f584b3d1537ffe (patch)
treea19599a44446816f69de2797af94a85b87dab99a /resources
parent2291eaac7509aadf30be407a6eb84cfa3d3a33d0 (diff)
CSIT-861: SW cryptodev perf tests
Change-Id: I687216ca43569542d38be681ca04c898010fc65d Signed-off-by: Jan Gelety <jgelety@cisco.com>
Diffstat (limited to 'resources')
-rw-r--r--resources/libraries/python/DUTSetup.py124
-rw-r--r--resources/libraries/python/VppConfigGenerator.py18
-rw-r--r--resources/libraries/robot/crypto/ipsec.robot7
-rw-r--r--resources/libraries/robot/performance/performance_setup.robot12
-rw-r--r--resources/libraries/robot/shared/default.robot58
5 files changed, 157 insertions, 62 deletions
diff --git a/resources/libraries/robot/crypto/ipsec.robot b/resources/libraries/robot/crypto/ipsec.robot
index 80d2937e37..d918a54159 100644
--- a/resources/libraries/robot/crypto/ipsec.robot
+++ b/resources/libraries/robot/crypto/ipsec.robot
@@ -305,7 +305,12 @@
| | | Run keyword | ${dut}.Add Unix CLI Listen | /run/vpp/cli.sock
| | | Run keyword | ${dut}.Add Unix Gid
| | | Run keyword | ${dut}.Add Api Segment Gid
-| | | Run keyword | ${dut}.Add DPDK SW Cryptodev | ${1}
+| | | ${socket_id}= | Set Variable | ${0}
+| | | ${sw_dev_count}= | Set Variable | ${1}
+| | | Run keyword | ${dut}.Add DPDK SW Cryptodev | aesni_mb | ${socket_id}
+| | | ... | ${sw_dev_count}
+| | | Run keyword | ${dut}.Add DPDK SW Cryptodev | aesni_gcm | ${socket_id}
+| | | ... | ${sw_dev_count}
| | Apply startup configuration on all VPP DUTs | restart_vpp=${FALSE}
| | Set up functional test
| | Run Keyword | Configure topology for ${ip_version} IPsec testing
diff --git a/resources/libraries/robot/performance/performance_setup.robot b/resources/libraries/robot/performance/performance_setup.robot
index 492815b9b6..68f84b664f 100644
--- a/resources/libraries/robot/performance/performance_setup.robot
+++ b/resources/libraries/robot/performance/performance_setup.robot
@@ -355,18 +355,24 @@
| | ... | *Arguments:*
| | ... | - topology_type - Topology type. Type: string
| | ... | - nic_model - Interface model. Type: string
+| | ... | - crypto_type - Crypto device type - HW_cryptodev or SW_cryptodev
+| | ... | (Optional). Type: string, default value: HW_cryptodev
| | ...
| | ... | *Example:*
| | ...
| | ... | \| Set up IPSec performance test suite \| L2 \
| | ... | \| Intel-X520-DA2 \|
| | ...
-| | [Arguments] | ${topology_type} | ${nic_model}
+| | [Arguments] | ${topology_type} | ${nic_model} | ${crypto_type}=HW_cryptodev
| | ...
| | Set up 3-node performance topology with DUT's NIC model
| | ... | ${topology_type} | ${nic_model}
-| | Configure crypto device on all DUTs | force_init=${True}
-| | Configure kernel module on all DUTs | igb_uio | force_load=${True}
+| | ${numvfs}= | Set Variable If
+| | ... | '${crypto_type}' == 'HW_cryptodev' | ${32}
+| | ... | '${crypto_type}' == 'SW_cryptodev' | ${0}
+| | Configure crypto device on all DUTs | force_init=${True} | numvfs=${numvfs}
+| | Run Keyword If | '${crypto_type}' == 'HW_cryptodev'
+| | ... | Configure kernel module on all DUTs | igb_uio | force_load=${True}
| Set up performance topology with containers
| | [Documentation]
diff --git a/resources/libraries/robot/shared/default.robot b/resources/libraries/robot/shared/default.robot
index 74ad8d3f09..4761ea8481 100644
--- a/resources/libraries/robot/shared/default.robot
+++ b/resources/libraries/robot/shared/default.robot
@@ -73,28 +73,31 @@
| Configure crypto device on all DUTs
| | [Documentation] | Verify if Crypto QAT device virtual functions are
| | ... | initialized on all DUTs. If parameter force_init is set to True, then
-| | ... | try to initialize.
+| | ... | try to initialize/disable.
| | ...
| | ... | *Arguments:*
-| | ... | - ${force_init} - Try to initialize. Type: boolean
+| | ... | - force_init - Force to initialize. Type: boolean
+| | ... | - numvfs - Number of VFs to initialize, 0 - disable the VFs
+| | ... | (Optional). Type: integer, default value: ${32}
| | ...
| | ... | *Example:*
| | ...
| | ... | \| Configure crypto device on all DUTs \| ${True} \|
| | ...
-| | [Arguments] | ${force_init}=${False}
+| | [Arguments] | ${force_init}=${False} | ${numvfs}=${32}
| | ...
| | ${duts}= | Get Matches | ${nodes} | DUT*
| | :FOR | ${dut} | IN | @{duts}
| | | Crypto Device Verify | ${nodes['${dut}']} | force_init=${force_init}
+| | | ... | numvfs=${numvfs}
| Configure kernel module on all DUTs
| | [Documentation] | Verify if specific kernel module is loaded on all DUTs.
| | ... | If parameter force_load is set to True, then try to initialize.
| | ...
| | ... | *Arguments:*
-| | ... | - ${module} - Module to verify. Type: string
-| | ... | - ${force_load} - Try to load module. Type: boolean
+| | ... | - module - Module to verify. Type: string
+| | ... | - force_load - Try to load module. Type: boolean
| | ...
| | ... | *Example:*
| | ...
@@ -242,6 +245,23 @@
| | :FOR | ${dut} | IN | @{duts}
| | | Run keyword | ${dut}.Add DPDK Dev Default TXD | ${txd}
+| Add DPDK Uio Driver on all DUTs
+| | [Documentation] | Add DPDK uio driver to VPP startup configuration on all
+| | ... | DUTs.
+| | ...
+| | ... | *Arguments:*
+| | ... | - uio_driver - Required uio driver. Type: string
+| | ...
+| | ... | *Example:*
+| | ...
+| | ... | \| Add DPDK Uio Driver on all DUTs \| igb_uio \|
+| | ...
+| | [Arguments] | ${uio_driver}
+| | ...
+| | ${duts}= | Get Matches | ${nodes} | DUT*
+| | :FOR | ${dut} | IN | @{duts}
+| | | Run keyword | ${dut}.Add DPDK Uio Driver | ${uio_driver}
+
| Add NAT to all DUTs
| | [Documentation] | Add NAT configuration to all DUTs.
| | ...
@@ -253,7 +273,7 @@
| | [Documentation] | Add Cryptodev to VPP startup configuration to all DUTs.
| | ...
| | ... | *Arguments:*
-| | ... | - ${count} - Number of QAT devices. Type: integer
+| | ... | - count - Number of QAT devices. Type: integer
| | ...
| | ... | *Example:*
| | ...
@@ -264,27 +284,33 @@
| | :FOR | ${dut} | IN | @{duts}
| | | Run keyword | ${dut}.Add DPDK Cryptodev | ${count}
-| Add crypto SW device on all DUTs
-| | [Documentation] | Add required number of crypto SW devices to VPP startup
-| | ... | configuration on all DUTs.
+| Add DPDK SW cryptodev on DUTs in 3-node single-link circular topology
+| | [Documentation] | Add required number of SW crypto devices of given type
+| | ... | to VPP startup configuration on all DUTs in 3-node single-link
+| | ... | circular topology.
| | ...
| | ... | *Arguments:*
-| | ... | - ${count} - Number of SW crypto devices. Type: integer
+| | ... | - sw_pmd_type - PMD type of SW crypto device. Type: string
+| | ... | - count - Number of SW crypto devices. Type: string
| | ...
| | ... | *Example:*
| | ...
-| | ... | \| Add SW cryptodev on all DUTs \| ${4} \|
+| | ... | \| Add DPDK SW cryptodev on DUTs in 3-node single-link circular\
+| | ... | topology \| aesni-mb \| ${2} \|
| | ...
-| | [Arguments] | ${count}
-| | ${duts}= | Get Matches | ${nodes} | DUT*
-| | :FOR | ${dut} | IN | @{duts}
-| | | Run keyword | ${dut}.Add DPDK SW Cryptodev | ${count}
+| | [Arguments] | ${sw_pmd_type} | ${count}
+| | ${socket_id}= | Get Interface Numa Node | ${nodes['DUT1']} | ${dut1_if2}
+| | Run keyword | DUT1.Add DPDK SW Cryptodev | ${sw_pmd_type} | ${socket_id}
+| | ... | ${count}
+| | ${socket_id}= | Get Interface Numa Node | ${nodes['DUT2']} | ${dut2_if1}
+| | Run keyword | DUT2.Add DPDK SW Cryptodev | ${sw_pmd_type} | ${socket_id}
+| | ... | ${count}
| Apply startup configuration on all VPP DUTs
| | [Documentation] | Write startup configuration and restart VPP on all DUTs.
| | ...
| | ... | *Arguments:*
-| | ... | - ${restart_vpp} - Whether to restart VPP (Optional). Type: boolean
+| | ... | - restart_vpp - Whether to restart VPP (Optional). Type: boolean
| | ...
| | ... | *Example:*
| | ...
diff --git a/resources/libraries/python/DUTSetup.py b/resources/libraries/python/DUTSetup.py
index bccf108524..d76a2f4096 100644
--- a/resources/libraries/python/DUTSetup.py
+++ b/resources/libraries/python/DUTSetup.py
@@ -19,6 +19,7 @@ from resources.libraries.python.topology import NodeType, Topology
from resources.libraries.python.ssh import SSH
from resources.libraries.python.constants import Constants
from resources.libraries.python.VatExecutor import VatExecutor
+from resources.libraries.python.VPPUtil import VPPUtil
class DUTSetup(object):
@@ -196,7 +197,7 @@ class DUTSetup(object):
ssh.connect(node)
cryptodev = Topology.get_cryptodev(node)
- cmd = 'cat /sys/bus/pci/devices/{}/sriov_numvfs'.\
+ cmd = 'cat /sys/bus/pci/devices/{0}/sriov_numvfs'.\
format(cryptodev.replace(':', r'\:'))
# Try to read number of VFs from PCI address of QAT device
@@ -206,7 +207,7 @@ class DUTSetup(object):
try:
sriov_numvfs = int(stdout)
except ValueError:
- logger.trace('Reading sriov_numvfs info failed on: {}'.
+ logger.trace('Reading sriov_numvfs info failed on {0}'.
format(node['host']))
else:
if sriov_numvfs != numvfs:
@@ -215,10 +216,10 @@ class DUTSetup(object):
# with numvfs
DUTSetup.crypto_device_init(node, numvfs)
else:
- raise RuntimeError('QAT device {} is not '
- 'initialized to {} on host: {}'.
- format(cryptodev, numvfs,
- node['host']))
+ raise RuntimeError('QAT device {0} is not '
+ 'initialized to {1} on host {2}'
+ .format(cryptodev, numvfs,
+ node['host']))
break
@staticmethod
@@ -230,26 +231,35 @@ class DUTSetup(object):
:type node: dict
:type numvfs: int
:returns: nothing
:raises RuntimeError: If QAT failed to initialize.
"""
+ cryptodev = Topology.get_cryptodev(node)
- ssh = SSH()
- ssh.connect(node)
+ # QAT device must be re-bound to kernel driver before initialization
+ driver = 'dh895xcc'
+ kernel_module = 'qat_dh895xcc'
+ current_driver = DUTSetup.get_pci_dev_driver(
+ node, cryptodev.replace(':', r'\:'))
- cryptodev = Topology.get_cryptodev(node)
+ DUTSetup.kernel_module_verify(node, kernel_module, force_load=True)
- # QAT device must be bind to kernel driver before initialization
- DUTSetup.pci_driver_unbind(node, cryptodev)
- DUTSetup.pci_driver_bind(node, cryptodev, "dh895xcc")
+ VPPUtil.stop_vpp_service(node)
+ if current_driver is not None:
+ DUTSetup.pci_driver_unbind(node, cryptodev)
+ DUTSetup.pci_driver_bind(node, cryptodev, driver)
+
+ ssh = SSH()
+ ssh.connect(node)
# Initialize QAT VFs
- ret_code, _, _ = ssh.exec_command(
- "sudo sh -c 'echo {} | tee /sys/bus/pci/devices/{}/sriov_numvfs'"
- .format(numvfs, cryptodev.replace(':', r'\:')))
+ if numvfs > 0:
+ cmd = 'echo "{0}" | tee /sys/bus/pci/devices/{1}/sriov_numvfs'.\
+ format(numvfs, cryptodev.replace(':', r'\:'), timeout=180)
+ ret_code, _, _ = ssh.exec_command_sudo("sh -c '{0}'".format(cmd))
- if int(ret_code) != 0:
- raise RuntimeError('Failed to initialize {} VFs on QAT device on '
- 'host: {}'.format(numvfs, node['host']))
+ if int(ret_code) != 0:
+ raise RuntimeError('Failed to initialize {0} VFs on QAT device '
+ ' on host {1}'.format(numvfs, node['host']))
@staticmethod
def pci_driver_unbind(node, pci_addr):
@@ -266,13 +276,13 @@ class DUTSetup(object):
ssh = SSH()
ssh.connect(node)
- ret_code, _, _ = ssh.exec_command(
- "sudo sh -c 'echo {} | tee /sys/bus/pci/devices/{}/driver/unbind'"
- .format(pci_addr, pci_addr.replace(':', r'\:')))
+ ret_code, _, _ = ssh.exec_command_sudo(
+ "sh -c 'echo {0} | tee /sys/bus/pci/devices/{1}/driver/unbind'"
+ .format(pci_addr, pci_addr.replace(':', r'\:')), timeout=180)
if int(ret_code) != 0:
- raise RuntimeError('Failed to unbind PCI device from driver on '
- 'host: {}'.format(node['host']))
+ raise RuntimeError('Failed to unbind PCI device {0} from driver on '
+ 'host {1}'.format(pci_addr, node['host']))
@staticmethod
def pci_driver_bind(node, pci_addr, driver):
@@ -291,13 +301,57 @@ class DUTSetup(object):
ssh = SSH()
ssh.connect(node)
- ret_code, _, _ = ssh.exec_command(
- "sudo sh -c 'echo {} | tee /sys/bus/pci/drivers/{}/bind'"
- .format(pci_addr, driver))
+ ret_code, _, _ = ssh.exec_command_sudo(
+ "sh -c 'echo {0} | tee /sys/bus/pci/drivers/{1}/bind'".format(
+ pci_addr, driver), timeout=180)
if int(ret_code) != 0:
- raise RuntimeError('Failed to bind PCI device to {} driver on '
- 'host: {}'.format(driver, node['host']))
+ raise RuntimeError('Failed to bind PCI device {0} to {1} driver on '
+ 'host {2}'.format(pci_addr, driver,
+ node['host']))
+
+ @staticmethod
+ def get_pci_dev_driver(node, pci_addr):
+ """Get current PCI device driver on node.
+
+ :param node: DUT node.
+ :param pci_addr: PCI device address.
+ :type node: dict
+ :type pci_addr: str
+ :returns: Driver or None
+ :raises RuntimeError: If PCI rescan or lspci command execution failed.
+ """
+ ssh = SSH()
+ ssh.connect(node)
+
+ for i in range(3):
+ logger.trace('Try {0}: Get interface driver'.format(i))
+ cmd = 'sh -c "echo 1 > /sys/bus/pci/rescan"'
+ ret_code, _, _ = ssh.exec_command_sudo(cmd)
+ if int(ret_code) != 0:
+ raise RuntimeError("'{0}' failed on '{1}'"
+ .format(cmd, node['host']))
+
+ cmd = 'lspci -vmmks {0}'.format(pci_addr)
+ ret_code, stdout, _ = ssh.exec_command(cmd)
+ if int(ret_code) != 0:
+ raise RuntimeError("'{0}' failed on '{1}'"
+ .format(cmd, node['host']))
+
+ for line in stdout.splitlines():
+ if len(line) == 0:
+ continue
+ name = None
+ value = None
+ try:
+ name, value = line.split("\t", 1)
+ except ValueError:
+ if name == "Driver:":
+ return None
+ if name == 'Driver:':
+ return value
+ else:
+ return None
@staticmethod
def kernel_module_verify(node, module, force_load=False):
@@ -309,7 +363,7 @@ class DUTSetup(object):
:param force_load: If True then try to load module.
:type node: dict
:type module: str
- :type force_init: bool
+ :type force_load: bool
:returns: nothing
:raises RuntimeError: If module is not loaded or failed to load.
"""
@@ -317,7 +371,7 @@ class DUTSetup(object):
ssh = SSH()
ssh.connect(node)
- cmd = 'grep -w {} /proc/modules'.format(module)
+ cmd = 'grep -w {0} /proc/modules'.format(module)
ret_code, _, _ = ssh.exec_command(cmd)
if int(ret_code) != 0:
@@ -325,8 +379,8 @@ class DUTSetup(object):
# Module is not loaded and we want to load it
DUTSetup.kernel_module_load(node, module)
else:
- raise RuntimeError('Kernel module {} is not loaded on host: {}'.
- format(module, node['host']))
+ raise RuntimeError('Kernel module {0} is not loaded on host '
+ '{1}'.format(module, node['host']))
@staticmethod
def kernel_module_load(node, module):
@@ -343,8 +397,8 @@ class DUTSetup(object):
ssh = SSH()
ssh.connect(node)
- ret_code, _, _ = ssh.exec_command_sudo("modprobe {}".format(module))
+ ret_code, _, _ = ssh.exec_command_sudo("modprobe {0}".format(module))
if int(ret_code) != 0:
- raise RuntimeError('Failed to load {} kernel module on host: {}'.
+ raise RuntimeError('Failed to load {0} kernel module on host {1}'.
format(module, node['host']))
@@ -230,26 +231,35 @@ class DUTSetup(object):
:type numvfs: int
:returns: nothing
- :raises RuntimeError: If QAT failed to initialize.
+ :raises RuntimeError: If failed to stop VPP or QAT failed to initialize.
"""
diff --git a/resources/libraries/python/VppConfigGenerator.py b/resources/libraries/python/VppConfigGenerator.py
index eccada9979..def23712e5 100644
--- a/resources/libraries/python/VppConfigGenerator.py
+++ b/resources/libraries/python/VppConfigGenerator.py
@@ -211,15 +211,19 @@ class VppConfigGenerator(object):
self.add_config_item(self._nodeconfig, '', path)
self.add_dpdk_uio_driver('igb_uio')
- def add_dpdk_sw_cryptodev(self, count):
- """Add DPDK Crypto SW device configuration.
-
- :param count: Number of crypto SW devices to add.
+ def add_dpdk_sw_cryptodev(self, sw_pmd_type, socket_id, count):
+ """Add DPDK SW Crypto device configuration.
+
+ :param sw_pmd_type: Type of SW crypto device PMD to add.
+ :param socket_id: Socket ID.
+ :param count: Number of SW crypto devices to add.
+ :type sw_pmd_type: str
+ :type socket_id: int
:type count: int
"""
- for i in range(count):
- cryptodev_config = 'vdev cryptodev_aesni_mb_pmd,socket_id={0}'.\
- format(str(i))
+ for _ in range(count):
+ cryptodev_config = 'vdev cryptodev_{0}_pmd,socket_id={1}'.\
+ format(sw_pmd_type, str(socket_id))
path = ['dpdk', cryptodev_config]
self.add_config_item(self._nodeconfig, '', path)